==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/CloudWatchEvents/DescribeRuleResponse.pm <==

package Paws::CloudWatchEvents::DescribeRuleResponse;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has Description => (is => 'ro', isa => 'Str');
  has EventBusName => (is => 'ro', isa => 'Str');
  has EventPattern => (is => 'ro', isa => 'Str');
  has ManagedBy => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has RoleArn => (is => 'ro', isa => 'Str');
  has ScheduleExpression => (is => 'ro', isa => 'Str');
  has State => (is => 'ro', isa => 'Str');

  has _request_id => (is => 'ro', isa => 'Str');

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::DescribeRuleResponse

=head1 ATTRIBUTES


=head2 Arn => Str

The Amazon Resource Name (ARN) of the rule.


=head2 Description => Str

The description of the rule.


=head2 EventBusName => Str

The event bus associated with the rule.


=head2 EventPattern => Str

The event pattern. For more information, see Event Patterns
(https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-and-event-patterns.html)
in the I<Amazon EventBridge User Guide>.


=head2 ManagedBy => Str

If this is a managed rule, created by an AWS service on your behalf,
this field displays the principal name of the AWS service that created
the rule.


=head2 Name => Str

The name of the rule.


=head2 RoleArn => Str

The Amazon Resource Name (ARN) of the IAM role associated with the
rule.


=head2 ScheduleExpression => Str

The scheduling expression: for example, C<"cron(0 20 * * ? *)"> or
C<"rate(5 minutes)">.


=head2 State => Str

Specifies whether the rule is enabled or disabled.

Valid values are: C<"ENABLED">, C<"DISABLED">
=head2 _request_id => Str


=cut

1;

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/CloudWatchEvents/DescribeRuleResponse.pm <==

package Paws::CloudWatchEvents::DescribeRuleResponse;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreatedBy => (is => 'ro', isa => 'Str');
  has Description => (is => 'ro', isa => 'Str');
  has EventBusName => (is => 'ro', isa => 'Str');
  has EventPattern => (is => 'ro', isa => 'Str');
  has ManagedBy => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has RoleArn => (is => 'ro', isa => 'Str');
  has ScheduleExpression => (is => 'ro', isa => 'Str');
  has State => (is => 'ro', isa => 'Str');

  has _request_id => (is => 'ro', isa => 'Str');

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::DescribeRuleResponse

=head1 ATTRIBUTES


=head2 Arn => Str

The Amazon Resource Name (ARN) of the rule.


=head2 CreatedBy => Str

The account ID of the user that created the rule. If you use C<PutRule>
to put a rule on an event bus in another account, the other account is
the owner of the rule, and the rule ARN includes the account ID for
that account. However, the value for C<CreatedBy> is the account ID as
the account that created the rule in the other account.


=head2 Description => Str

The description of the rule.


=head2 EventBusName => Str

The name of the event bus associated with the rule.


=head2 EventPattern => Str

The event pattern. For more information, see Events and Event Patterns
(https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-and-event-patterns.html)
in the I<Amazon EventBridge User Guide>.


=head2 ManagedBy => Str

If this is a managed rule, created by an AWS service on your behalf,
this field displays the principal name of the AWS service that created
the rule.


=head2 Name => Str

The name of the rule.


=head2 RoleArn => Str

The Amazon Resource Name (ARN) of the IAM role associated with the
rule.


=head2 ScheduleExpression => Str

The scheduling expression. For example, "cron(0 20 * * ? *)", "rate(5
minutes)".


=head2 State => Str

Specifies whether the rule is enabled or disabled.

Valid values are: C<"ENABLED">, C<"DISABLED">
=head2 _request_id => Str


=cut

1;
